
# Slot: source


the source of an attributed description

URI: [linkml:alt_description_source](https://w3id.org/linkml/alt_description_source)


## Domain and Range

[AltDescription](AltDescription.md) &#8594;  <sub>1..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [AltDescription](AltDescription.md)
